==> istio-model-v1alpha3-5.11.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/PortBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PortBuilder extends io.fabric8.istio.api.networking.v1alpha3.PortFluentImpl<io.fabric8.istio.api.networking.v1alpha3.PortBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1alpha3.Port,io.fabric8.istio.api.networking.v1alpha3.PortBuilder>{
  public PortBuilder() {
    this(false);
  }
  public PortBuilder(java.lang.Boolean validationEnabled) {
    this(new Port(), validationEnabled);
  }
  public PortBuilder(io.fabric8.istio.api.networking.v1alpha3.PortFluent<?> fluent) {
    this(fluent, false);
  }
  public PortBuilder(io.fabric8.istio.api.networking.v1alpha3.PortFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Port(), validationEnabled);
  }
  public PortBuilder(io.fabric8.istio.api.networking.v1alpha3.PortFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.Port instance) {
    this(fluent, instance, false);
  }
  public PortBuilder(io.fabric8.istio.api.networking.v1alpha3.PortFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.Port instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withNumber(instance.getNumber()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withTargetPort(instance.getTargetPort()); 
    this.validationEnabled = validationEnabled; 
  }
  public PortBuilder(io.fabric8.istio.api.networking.v1alpha3.Port instance) {
    this(instance,false);
  }
  public PortBuilder(io.fabric8.istio.api.networking.v1alpha3.Port instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withNumber(instance.getNumber()); 
    this.withProtocol(instance.getProtocol()); 
    this.withTargetPort(instance.getTargetPort()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1alpha3.PortFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1alpha3.Port build() {
    Port buildable = new Port(fluent.getName(),fluent.getNumber(),fluent.getProtocol(),fluent.getTargetPort());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortBuilder that = (PortBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/PortBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PortBuilder extends PortFluentImpl<PortBuilder> implements VisitableBuilder<Port,PortBuilder>{
  public PortBuilder() {
    this(false);
  }
  public PortBuilder(Boolean validationEnabled) {
    this(new Port(), validationEnabled);
  }
  public PortBuilder(PortFluent<?> fluent) {
    this(fluent, false);
  }
  public PortBuilder(PortFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Port(), validationEnabled);
  }
  public PortBuilder(PortFluent<?> fluent,Port instance) {
    this(fluent, instance, false);
  }
  public PortBuilder(PortFluent<?> fluent,Port instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withNumber(instance.getNumber()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withTargetPort(instance.getTargetPort()); 
    this.validationEnabled = validationEnabled; 
  }
  public PortBuilder(Port instance) {
    this(instance,false);
  }
  public PortBuilder(Port instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withNumber(instance.getNumber()); 
    this.withProtocol(instance.getProtocol()); 
    this.withTargetPort(instance.getTargetPort()); 
    this.validationEnabled = validationEnabled; 
  }
  PortFluent<?> fluent;
  Boolean validationEnabled;
  public Port build() {
    Port buildable = new Port(fluent.getName(),fluent.getNumber(),fluent.getProtocol(),fluent.getTargetPort());
    return buildable;
  }
  
}
